# Changelog

## [0.1.2](https://github.com/pvliesdonk/pvl-webtools/compare/v0.1.1...v0.1.2) (2026-01-03)


### Bug Fixes

* Add attestations permission to release-please workflow ([#10](https://github.com/pvliesdonk/pvl-webtools/issues/10)) ([ea067df](https://github.com/pvliesdonk/pvl-webtools/commit/ea067dfef87c360c6b02ab29ff5c63655e5367a5))
* Add missing permissions for Docker attestation ([#9](https://github.com/pvliesdonk/pvl-webtools/issues/9)) ([72c8eed](https://github.com/pvliesdonk/pvl-webtools/commit/72c8eed79bdcd19161ba48553045937eb5e41db8))
* Chain release workflows and fix Dockerfile ([#7](https://github.com/pvliesdonk/pvl-webtools/issues/7)) ([3ea71d1](https://github.com/pvliesdonk/pvl-webtools/commit/3ea71d12fb5a4548a39a42f46404d0ec40860c96))

## [0.1.1](https://github.com/pvliesdonk/pvl-webtools/compare/v0.1.0...v0.1.1) (2026-01-03)


### Features

* Add configurable FetchConfig and comprehensive documentation ([#3](https://github.com/pvliesdonk/pvl-webtools/issues/3)) ([af039c3](https://github.com/pvliesdonk/pvl-webtools/commit/af039c32780dafc27cf884b67389cd062c4336c9))
* Add Docker support and release automation ([#4](https://github.com/pvliesdonk/pvl-webtools/issues/4)) ([9809906](https://github.com/pvliesdonk/pvl-webtools/commit/98099062f24b98638b8811790659713c41f63146))
* add markitdown for LLM-friendly markdown extraction ([#1](https://github.com/pvliesdonk/pvl-webtools/issues/1)) ([628789a](https://github.com/pvliesdonk/pvl-webtools/commit/628789a42d31c976c3bd7c1d70ea70df14f8b7fc))
* Initial release of pvl-webtools ([a832459](https://github.com/pvliesdonk/pvl-webtools/commit/a832459eb2cc6d008f10a5b7da13c9552e083bdc))
* Replace manual release with release-please automation ([#5](https://github.com/pvliesdonk/pvl-webtools/issues/5)) ([a998326](https://github.com/pvliesdonk/pvl-webtools/commit/a99832654058e2b8caa20642f07bb1da9ca821e7))


### Miscellaneous

* add pre-commit hooks and CLAUDE.md ([ade6777](https://github.com/pvliesdonk/pvl-webtools/commit/ade67776a17a266c326e099c73068e0ffa40ad4b))


### Continuous Integration

* add PyPI publish and Claude workflows ([#2](https://github.com/pvliesdonk/pvl-webtools/issues/2)) ([431a3b0](https://github.com/pvliesdonk/pvl-webtools/commit/431a3b0b302a6c1fc35f4655e028531c91bf7089))
